==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/QrtzBlobTriggers.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Arrays;
import pl.topteam.dps.enums.GrupaTriggerow;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class QrtzBlobTriggers extends GenericDPSObject {
    /**
     * QRTZ_BLOB_TRIGGERS.SCHED_NAME
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String schedName;

    /**
     * QRTZ_BLOB_TRIGGERS.TRIGGER_NAME
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String triggerName;

    /**
     * QRTZ_BLOB_TRIGGERS.TRIGGER_GROUP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private GrupaTriggerow triggerGroup;

    /**
     * QRTZ_BLOB_TRIGGERS.BLOB_DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private byte[] blobData;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return QRTZ_BLOB_TRIGGERS.SCHED_NAME
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSchedName() {
        return schedName;
    }

    /**
     * QRTZ_BLOB_TRIGGERS.SCHED_NAME
     *
     * @param schedName
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSchedName(String schedName) {
        this.schedName = schedName == null ? null : schedName.trim();
    }

    /**
     * @return QRTZ_BLOB_TRIGGERS.TRIGGER_NAME
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTriggerName() {
        return triggerName;
    }

    /**
     * QRTZ_BLOB_TRIGGERS.TRIGGER_NAME
     *
     * @param triggerName
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTriggerName(String triggerName) {
        this.triggerName = triggerName == null ? null : triggerName.trim();
    }

    /**
     * @return QRTZ_BLOB_TRIGGERS.TRIGGER_GROUP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public GrupaTriggerow getTriggerGroup() {
        return triggerGroup;
    }

    /**
     * QRTZ_BLOB_TRIGGERS.TRIGGER_GROUP
     *
     * @param triggerGroup
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTriggerGroup(GrupaTriggerow triggerGroup) {
        this.triggerGroup = triggerGroup;
    }

    /**
     * @return QRTZ_BLOB_TRIGGERS.BLOB_DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public byte[] getBlobData() {
        return blobData;
    }

    /**
     * QRTZ_BLOB_TRIGGERS.BLOB_DATA
     *
     * @param blobData
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setBlobData(byte[] blobData) {
        this.blobData = blobData;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        QrtzBlobTriggers other = (QrtzBlobTriggers) that;
        return (this.getSchedName() == null ? other.getSchedName() == null : this.getSchedName().equals(other.getSchedName()))
            && (this.getTriggerName() == null ? other.getTriggerName() == null : this.getTriggerName().equals(other.getTriggerName()))
            && (this.getTriggerGroup() == null ? other.getTriggerGroup() == null : this.getTriggerGroup().equals(other.getTriggerGroup()))
            && (Arrays.equals(this.getBlobData(), other.getBlobData()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSchedName() == null) ? 0 : getSchedName().hashCode());
        result = prime * result + ((getTriggerName() == null) ? 0 : getTriggerName().hashCode());
        result = prime * result + ((getTriggerGroup() == null) ? 0 : getTriggerGroup().hashCode());
        result = prime * result + (Arrays.hashCode(getBlobData()));
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", schedName=").append(schedName);
        sb.append(", triggerName=").append(triggerName);
        sb.append(", triggerGroup=").append(triggerGroup);
        sb.append(", blobData=").append(blobData);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/QrtzBlobTriggers.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Arrays;
import pl.topteam.dps.enums.GrupaTriggerow;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class QrtzBlobTriggers extends GenericDPSObject {
    /**
     * QRTZ_BLOB_TRIGGERS.SCHED_NAME
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String schedName;

    /**
     * QRTZ_BLOB_TRIGGERS.TRIGGER_NAME
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String triggerName;

    /**
     * QRTZ_BLOB_TRIGGERS.TRIGGER_GROUP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private GrupaTriggerow triggerGroup;

    /**
     * QRTZ_BLOB_TRIGGERS.BLOB_DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private byte[] blobData;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return QRTZ_BLOB_TRIGGERS.SCHED_NAME
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSchedName() {
        return schedName;
    }

    /**
     * QRTZ_BLOB_TRIGGERS.SCHED_NAME
     *
     * @param schedName
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSchedName(String schedName) {
        this.schedName = schedName == null ? null : schedName.trim();
    }

    /**
     * @return QRTZ_BLOB_TRIGGERS.TRIGGER_NAME
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTriggerName() {
        return triggerName;
    }

    /**
     * QRTZ_BLOB_TRIGGERS.TRIGGER_NAME
     *
     * @param triggerName
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTriggerName(String triggerName) {
        this.triggerName = triggerName == null ? null : triggerName.trim();
    }

    /**
     * @return QRTZ_BLOB_TRIGGERS.TRIGGER_GROUP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public GrupaTriggerow getTriggerGroup() {
        return triggerGroup;
    }

    /**
     * QRTZ_BLOB_TRIGGERS.TRIGGER_GROUP
     *
     * @param triggerGroup
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTriggerGroup(GrupaTriggerow triggerGroup) {
        this.triggerGroup = triggerGroup;
    }

    /**
     * @return QRTZ_BLOB_TRIGGERS.BLOB_DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public byte[] getBlobData() {
        return blobData;
    }

    /**
     * QRTZ_BLOB_TRIGGERS.BLOB_DATA
     *
     * @param blobData
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setBlobData(byte[] blobData) {
        this.blobData = blobData;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        QrtzBlobTriggers other = (QrtzBlobTriggers) that;
        return (this.getSchedName() == null ? other.getSchedName() == null : this.getSchedName().equals(other.getSchedName()))
            && (this.getTriggerName() == null ? other.getTriggerName() == null : this.getTriggerName().equals(other.getTriggerName()))
            && (this.getTriggerGroup() == null ? other.getTriggerGroup() == null : this.getTriggerGroup().equals(other.getTriggerGroup()))
            && (Arrays.equals(this.getBlobData(), other.getBlobData()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSchedName() == null) ? 0 : getSchedName().hashCode());
        result = prime * result + ((getTriggerName() == null) ? 0 : getTriggerName().hashCode());
        result = prime * result + ((getTriggerGroup() == null) ? 0 : getTriggerGroup().hashCode());
        result = prime * result + (Arrays.hashCode(getBlobData()));
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", schedName=").append(schedName);
        sb.append(", triggerName=").append(triggerName);
        sb.append(", triggerGroup=").append(triggerGroup);
        sb.append(", blobData=").append(blobData);
        sb.append("]");
        return sb.toString();
    }
}
